@@ -1,7 +1,6 @@
 # -*- coding: utf_8 -*-
 """Semantic Grep Helpers."""
 import multiprocessing
-from argparse import Namespace
 
 from semgrep import semgrep_main
 
@@ -13,32 +12,24 @@ except NotImplementedError:
 
 def call_semgrep(paths, scan_rules):
     """Call Semgrep."""
-    args = Namespace(
-        autofix=False,
+    return semgrep_main.main(
+        target=paths,
+        pattern=None,
+        lang=None,
         config=scan_rules,
-        dangerously_allow_arbitrary_code_execution_from_rules=False,
-        dump_ast=False,
-        error=False,
+        generate_config=False,
+        no_rewrite_rule_ids=False,
+        jobs=CPU_COUNT,
+        include=[],
+        include_dir=[],
         exclude=[],
         exclude_dir=[],
         exclude_tests=False,
-        generate_config=False,
-        include=[],
-        include_dir=[],
-        jobs=CPU_COUNT,
-        json=True,
-        lang=None,
-        no_rewrite_rule_ids=False,
-        output=None,
-        pattern=None,
-        precommit=False,
+        json_format=True,
+        sarif=False,
+        output_destination=None,
         quiet=True,
-        r2c=False,
         strict=False,
-        target=paths,
-        test=False,
-        test_ignore_todo=False,
-        validate=False,
-        verbose=False,
-        version=False)
-    return semgrep_main.main(args)
+        exit_on_error=False,
+        autofix=False,
+        dangerously_allow_arbitrary_code_execution_from_rules=False)
